@@ -57,7 +57,8 @@ pub fn read_phyloxml(filename: String, tree: &mut ArenaTree<String>) {
         Ok(xml) => xml,
         Err(_err) => {
             eprintln!("\nERROR:\nSomething went wrong when parsing the input file.");
-            eprintln!("It seems this is not a xml file");
+            eprintln!("It seems this is not a correct xml file:");
+            eprintln!("{}",_err);
             std::process::exit(1);
         },
     };
@@ -165,7 +166,8 @@ pub fn read_recphyloxml_multi(
         Ok(contents) => contents,
         Err(_err) => {
             eprintln!("\nERROR:\nSomething went wrong when parsing the input file.");
-            eprintln!("It seems this is not a xml file");
+            eprintln!("It seems this is not a correct xml file:");
+            eprintln!("{}",_err);
             std::process::exit(1);
         },
     };
@@ -312,7 +314,6 @@ pub fn phyloxml_processing(
         real_length(&mut tree, root, &mut 0.0, & options);
         if options.tidy{
             check_contour_postorder_tidy_tree(&mut tree, root, & options, & config);
-            // shift_mod_xy(&mut tree, root, &mut 0.0, &mut 0.0);
             set_middle_postorder(&mut tree, root);
         }
     }
@@ -483,6 +484,10 @@ pub fn recphyloxml_processing(
         // Egalise les feuilles
         let largest_y  = sp_tree.get_largest_y();
         set_leaves_y_values(sp_tree, root, largest_y);
+    } else {
+        if options.tidy{
+            check_contour_postorder_tidy_tree(&mut sp_tree, root, & options, & config);
+        }
     }
     // ---------------------------------------------------------
     // OPTIONAL Scale the heigt if needed
